==> lxqt-config-0.9.0.tar.xz: lxqt-config-0.9.0/lxqt-config-file-associations/translations/lxqt-config-file-associations_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>ApplicationChooser</name>
    <message>
        <location filename="../applicationchooser.ui" line="14"/>
        <source>ApplicationChooser</source>
        <translation>Выбор приложения</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="46"/>
        <source>Pick an application for:</source>
        <translation>Выбрать приложение для:</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="110"/>
        <source>1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="115"/>
        <source>Applications that handle JPEG</source>
        <translation>Приложения, которые поддерживают JPEG</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="124"/>
        <location filename="../applicationchooser.ui" line="129"/>
        <location filename="../applicationchooser.ui" line="139"/>
        <location filename="../applicationchooser.ui" line="144"/>
        <source>New Subitem</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="135"/>
        <location filename="../applicationchooser.cpp" line="85"/>
        <source>Other applications</source>
        <translation>Другие приложения</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="86"/>
        <source>Applications that handle %1</source>
        <translation>Приложение, которое поддерживает %1</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="114"/>
        <source>No applications found</source>
        <translation>Не найдены приложения</translation>
    </message>
</context>
<context>
    <name>MimetypeViewer</name>
    <message>
        <location filename="../mimetypeviewer.cpp" line="157"/>
        <location filename="../mimetypeviewer.cpp" line="208"/>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="204"/>
        <source>&amp;Change...</source>
        <translation>&amp;Изменить...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="209"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Выбрать...</translation>
    </message>
</context>
<context>
    <name>mimetypeviewer</name>
    <message>
        <location filename="../mimetypeviewer.ui" line="20"/>
        <source>File Associations</source>
        <translation>Ассоциация файлов</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="56"/>
        <source>Default application</source>
        <translation>Приложение по умолчанию</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="68"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Выбрать...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="117"/>
        <source>TextLabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="124"/>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="144"/>
        <source>Patterns</source>
        <translation>Шаблоны</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="156"/>
        <source>*.txt *.xml</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="173"/>
        <source>MIME type</source>
        <translation>MIME-тип</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="191"/>
        <source>Icon</source>
        <translation>Значок</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="198"/>
        <source>Description</source>
        <translation>Описание</translation>
    </message>
</context>
</TS>

==> lxqt-config_0.14.1.orig.tar.xz: lxqt-config-0.14.1/lxqt-config-file-associations/translations/lxqt-config-file-associations_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>ApplicationChooser</name>
    <message>
        <location filename="../applicationchooser.ui" line="14"/>
        <source>ApplicationChooser</source>
        <translation>Выбор приложения</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="46"/>
        <source>Pick an application for:</source>
        <translation>Выбрать приложение для:</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="110"/>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="115"/>
        <source>Applications that handle JPEG</source>
        <translation>Приложения, которые поддерживают JPEG</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="124"/>
        <location filename="../applicationchooser.ui" line="129"/>
        <location filename="../applicationchooser.ui" line="139"/>
        <location filename="../applicationchooser.ui" line="144"/>
        <source>New Subitem</source>
        <translation>Новый элемент</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="135"/>
        <location filename="../applicationchooser.cpp" line="113"/>
        <source>Other applications</source>
        <translation>Другие приложения</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="114"/>
        <source>Applications that handle %1</source>
        <translation>Приложения, которые поддерживают %1</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="151"/>
        <source>No applications found</source>
        <translation>Приложения не найдены</translation>
    </message>
</context>
<context>
    <name>MimetypeViewer</name>
    <message>
        <location filename="../mimetypeviewer.cpp" line="156"/>
        <location filename="../mimetypeviewer.cpp" line="207"/>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="203"/>
        <source>&amp;Change...</source>
        <translation>&amp;Изменить...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="208"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Выбрать...</translation>
    </message>
</context>
<context>
    <name>mimetypeviewer</name>
    <message>
        <location filename="../mimetypeviewer.ui" line="20"/>
        <source>File Associations</source>
        <translation>Ассоциации файлов</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="56"/>
        <source>Default application</source>
        <translation>Приложение по умолчанию</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="68"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Выбрать...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="117"/>
        <source>TextLabel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="124"/>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="144"/>
        <source>Patterns</source>
        <translation>Шаблоны</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="156"/>
        <source>*.txt *.xml</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="173"/>
        <source>MIME type</source>
        <translation>MIME-тип</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="191"/>
        <source>Icon</source>
        <translation>Значок</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="198"/>
        <source>Description</source>
        <translation>Описание</translation>
    </message>
</context>
</TS>
